@@ -1,12 +1,15 @@
 from __future__ import division
 
-from numpy_sugar import epsilon
 from numpy import asarray, atleast_1d, exp, log, newaxis
 
+from numpy_sugar import epsilon
+
 from optimix import Function, Scalar
 
+from ..util.classes import NamedClass
 
-class EyeCov(Function):
+
+class EyeCov(NamedClass, Function):
     r"""Identity covariance function.
 
     The mathematical representation is
@@ -46,10 +49,18 @@ class EyeCov(Function):
         [[2.5 0.  0. ]
          [0.  2.5 0. ]
          [0.  0.  2.5]]
+        >>> print(cov)
+        EyeCov()
+          scale: 2.5
+        >>> cov.name = "identity"
+        >>> print(cov)
+        EyeCov(): identity
+          scale: 2.5
     """
 
     def __init__(self):
         Function.__init__(self, logscale=Scalar(0.0))
+        NamedClass.__init__(self)
 
     @property
     def scale(self):
@@ -102,3 +113,12 @@ class EyeCov(Function):
             :math:`s \delta[\mathrm x_0 = \mathrm x_1]`.
         """
         return dict(logscale=self.value(x0, x1))
+
+    def __str__(self):
+        tname = type(self).__name__
+        msg = "{}()".format(tname)
+        if self.name is not None:
+            msg += ": {}".format(self.name)
+        msg += "\n"
+        msg += "  scale: {}".format(self.scale)
+        return msg
