@@ -1,12 +1,15 @@
 from __future__ import division
 
-from numpy_sugar import epsilon
 from numpy import exp, log, stack
 
+from numpy_sugar import epsilon
+
 from optimix import Function, Scalar
 
+from ..util.classes import NamedClass
 
-class LinearCov(Function):
+
+class LinearCov(NamedClass, Function):
     r"""Linear covariance function.
 
     The mathematical representation is
@@ -20,6 +23,7 @@ class LinearCov(Function):
 
     def __init__(self):
         Function.__init__(self, logscale=Scalar(0.0))
+        NamedClass.__init__(self)
 
     @property
     def scale(self):
@@ -74,3 +78,12 @@ class LinearCov(Function):
         x0 = stack(x0, axis=0)
         x1 = stack(x1, axis=0)
         return dict(logscale=self.scale * x0.dot(x1.T))
+
+    def __str__(self):
+        tname = type(self).__name__
+        msg = "{}()".format(tname)
+        if self.name is not None:
+            msg += ": {}".format(self.name)
+        msg += "\n"
+        msg += "  scale: {}".format(self.scale)
+        return msg
