@@ -1,21 +1,21 @@
 from .check import check_economic_qs, check_covariates, check_outcome
-from .io import wprint
 from .hsolve import hsolve
 from .eigen import economic_qs_zeros
 from . import numbers
+from . import classes
 from .normalise import normalise_outcome, normalise_covariance, normalise_covariates
 
 log2pi = 1.837877066409345339081937709124758839607238769531250
 
 __all__ = [
-    "check_economic_qs",
     "check_covariates",
+    "check_economic_qs",
     "check_outcome",
-    "wprint",
+    "classes",
+    "economic_qs_zeros",
     "hsolve",
-    "normalise_outcome",
     "normalise_covariance",
     "normalise_covariates",
-    "economic_qs_zeros",
+    "normalise_outcome",
     "numbers",
 ]
